======
API
======

.. automodule:: clyther
   :members:
   :undoc-members:
    
   .. autoclass:: kernel
       :members:
       :undoc-members:
      
   .. autofunction:: global_work_size
   
   .. autofunction:: local_work_size
      
   .. autofunction:: cache
   
   .. autoclass:: task
       :members:
       :undoc-members:
        
.. automodule:: clyther.runtime
   :members:
   :undoc-members:

.. automodule:: clyther.array
   :members:
   :undoc-members:

   .. autoclass:: CLArrayContext
       :members:
       :undoc-members:

.. automodule:: clyther.runtime
   :members:
   :undoc-members:
   
.. automodule:: clyther.rttt
   :members:
   
   
.. automodule:: clyther.pipeline
   :members: create_kernel_source